@@ -1,13 +1,11 @@
-from dda_python_terraform import *
+from dda_python_terraform import Terraform
 from .devops_terraform_build import DevopsTerraformBuild
 
-
 def add_aws_backend_properties_mixin_config(config, account_name):
     config.update({'AwsBackendPropertiesMixin':
                    {'account_name': account_name}})
     return config
 
-
 class AwsBackendPropertiesMixin(DevopsTerraformBuild):
 
     def __init__(self, project, config):
@@ -38,14 +36,14 @@ class AwsBackendPropertiesMixin(DevopsTerraformBuild):
         pass
 
     def init_client(self):
-        tf = Terraform(working_dir=self.build_path(), terraform_version=self.terraform_version)
-        tf.init(backend_config=self.backend_config)
-        self.print_terraform_command(tf)
+        terraform = Terraform(working_dir=self.build_path(), terraform_semantic_version=self.terraform_semantic_version)
+        terraform.init(backend_config=self.backend_config)
+        self.print_terraform_command(terraform)
         if self.use_workspace:
             try:
-                tf.workspace('select', self.stage)
-                self.print_terraform_command(tf)
+                terraform.workspace('select', self.stage)
+                self.print_terraform_command(terraform)
             except:
-                tf.workspace('new', self.stage)
-                self.print_terraform_command(tf)
-        return tf
+                terraform.workspace('new', self.stage)
+                self.print_terraform_command(terraform)
+        return terraform
