@@ -1,9 +1,8 @@
-from subprocess import run
-from .python_util import filter_none
-from pkg_resources import *
-from .devops_build import DevopsBuild, create_devops_build_config
 import sys
-
+from subprocess import run
+from pkg_resources import resource_string
+from .python_util import filter_none
+from .devops_build import DevopsBuild, create_devops_build_config
 
 def create_devops_docker_build_config(stage,
                                       project_root_path,
@@ -20,7 +19,7 @@ def create_devops_docker_build_config(stage,
     ret.update({'dockerhub_user': dockerhub_user,
                 'dockerhub_password': dockerhub_password,
                 'use_package_common_files': use_package_common_files,
-                'docker_build_commons_dir_name': docker_build_commons_dir_name, 
+                'docker_build_commons_dir_name': docker_build_commons_dir_name,
                 'build_commons_path': build_commons_path,
                 'docker_publish_tag': docker_publish_tag, })
     return ret
@@ -44,10 +43,10 @@ class DevopsDockerBuild(DevopsBuild):
         return '/'.join(filter_none(mylist)) + '/'
 
     def copy_build_resource_file_from_package(self, name):
-        run('mkdir -p ' + self.build_path() + '/image/resources', shell=True)
+        run('mkdir -p ' + self.build_path() + '/image/resources', shell=True, check=True)
         my_data = resource_string(
             __name__, "src/main/resources/docker/" + name)
-        with open(self.build_path() + '/' + name, "w") as output_file:
+        with open(self.build_path() + '/' + name, "w", encoding="utf-8") as output_file:
             output_file.write(my_data.decode(sys.stdout.encoding))
 
     def copy_build_resources_from_package(self):
@@ -56,7 +55,7 @@ class DevopsDockerBuild(DevopsBuild):
 
     def copy_build_resources_from_dir(self):
         run('cp -f ' + self.docker_build_commons_path() +
-            '* ' + self.build_path(), shell=True)
+            '* ' + self.build_path(), shell=True, check=True)
 
     def initialize_build_dir(self):
         super().initialize_build_dir()
@@ -64,34 +63,34 @@ class DevopsDockerBuild(DevopsBuild):
             self.copy_build_resources_from_package()
         else:
             self.copy_build_resources_from_dir()
-        run('cp -r image ' + self.build_path(), shell=True)
-        run('cp -r test ' + self.build_path(), shell=True)
+        run('cp -r image ' + self.build_path(), shell=True, check=True)
+        run('cp -r test ' + self.build_path(), shell=True, check=True)
 
     def image(self):
         run('docker build -t ' + self.name() +
             ' --file ' + self.build_path() + '/image/Dockerfile '
-            + self.build_path() + '/image', shell=True)
+            + self.build_path() + '/image', shell=True, check=True)
 
     def drun(self):
         run('docker run --expose 8080 -it --entrypoint="" ' +
-            self.name() + ' /bin/bash', shell=True)
+            self.name() + ' /bin/bash', shell=True, check=True)
 
     def dockerhub_login(self):
         run('docker login --username ' + self.dockerhub_user +
-            ' --password ' + self.dockerhub_password, shell=True)
+            ' --password ' + self.dockerhub_password, shell=True, check=True)
 
     def dockerhub_publish(self):
-        if(self.docker_publish_tag is not None):
+        if self.docker_publish_tag is not None:
             run('docker tag ' + self.name() + ' ' + self.dockerhub_user +
-            '/' + self.name() + ':' + self.docker_publish_tag, shell=True)
+            '/' + self.name() + ':' + self.docker_publish_tag, shell=True, check=True)
             run('docker push ' + self.dockerhub_user +
-            '/' + self.name() + ':' + self.docker_publish_tag, shell=True)
+            '/' + self.name() + ':' + self.docker_publish_tag, shell=True, check=True)
         run('docker tag ' + self.name() + ' ' + self.dockerhub_user +
-            '/' + self.name() + ':latest', shell=True)
+            '/' + self.name() + ':latest', shell=True, check=True)
         run('docker push ' + self.dockerhub_user +
-        '/' + self.name() + ':latest', shell=True)
+        '/' + self.name() + ':latest', shell=True, check=True)
 
     def test(self):
         run('docker build -t ' + self.name() + '-test ' +
             '--file ' + self.build_path() + '/test/Dockerfile '
-            + self.build_path() + '/test', shell=True)
+            + self.build_path() + '/test', shell=True, check=True)
